
import Vue from 'vue'
import iview from 'iview'
import capt from 'capt-main'
import ispwebstore from './store/ispwebstore.js'
import { meObjCovion, axiosConfig } from '@/router/meobjcovion'
import config from '_s/config.json'
import apilist from '_s/apilist.json'
import 'iview/dist/styles/iview.css'
import 'capt-main/dist/capt-main.css'
import './mainstyle.css'
import mycomponents from './router'
Vue.use(iview)
// axios.onResponseError(error => {
//   const code = parseInt(error.response && error.response.status)
//   console.dir(code)
// })
/**
 * 错误示范：
 *
 * 自定义组件命名，切记不能和iview组件名名一样，否则无法运行，如下错误命名方法
 *
 * Table1.vue组件内的,name命名为，Table，可iview内也有这个命名，这样就无法运行了
 * export default {
        name: 'Table',
        ...
   }
 *
 */
/**
 * 如下的keyname对象，用时这样：store.state.keyname.xxx
 * vuexs: {
 *  keyname: uservuexs
 * }
*/
/**
 * capt.options -- 配置
 * el              -- html > body你的 div ID
 * components      -- 注册组件，
 * vuexs           -- 是本地的store
 * beforeLogin     -- 登录前
 * loginMounted    -- 成功登录后
 * meObjCovion:    -- 如果左边菜单json无法满足就写一个转换
 * axiosconfig:    -- axios全局配置，可以自定义每次的请求，和响应，完成的事件
 * baseUrl         -- 本地开发服务端请求配置
 * - dev，pro配服务端url，token如果支持url可以这么配，
 * - 本地开发推荐配置config/index.js内21行，代理服务
 * api路径配置
 * login，登录
 * logout 登出
 * verificon 验证码
 * userinfo 用户信息
 */

/**
 * capt.config -- 配置，头部显示
 * capt.config = {
 *    systmename: 'admin-后台管理平台',
 *    systmelogo: 'md-color-fill'
 *    theme: 'light' --主题，默认是黑色(theme: '')，灰白色 light
 *   }
 *
 */

/**
 * 全局事件
 *
 * 注册一个onresize事件，改变窗口大小就会调用，自己组件内的自定义的方法，
 * 1,2步
 * welcome.vue
 *  methods: {
 *    // 1，
 *    welcomewinresize () {
 *    // 改变窗口后触发这里
 *
 *    }
 *  },
 *  mounted () {
 *   // 2，
 *    this.$store.commit('setWinSize', this.welcomewinresize)
 *  }
 *
 */

 /**
 * 头部进度条用法，如下是某个组件内
 * methods: {
 * getData () {
 *    1，从0%开启
 *    this.$Loading.start();
 *       $.ajax({
 *         url: '/api/someurl',
 *         type: 'get',
 *         success: () => {
 *             2，跑完100%
 *             this.$Loading.finish();
 *             2.1 精确用法,直接如下一种就行
 *             this.$Loading.update(0%到100%)
 *         }
 *         error: () => {
 *             3，错误变色
 *             this.$Loading.error();
 *         }
 *     });
 *   }
 * }
 *
 */

 /**
  * 真实接口
  * baseUrl: {
  * login: '/devapi/login', -- 登录
  * logout: '/devapi/logout', -- 登出
  * verificon: '/devapi/imgVerify', -- 验证码
  * userinfo: '/devapi/api/user/info', --用户信息
  * menutree: '/static/menu.json' --左边菜单
  * }
  *
  */

  /**
   * 
   * 带参数路由
   * 1, 数据库字段内
   * /abc:id
   * 1.1 动态内跳转请求
   * this.$router.push({ path: `/main/abc/${params.row.id}`})
   * 1.2 静态内跳转请求
   * <router-link :to="{ path: `/main/abc/${params.row.id}`}">/abc/1</router-link>
   * 
   */

capt.config = {
  systmename: 'ISP 信息服务管理平台',
  systmelogo: 'md-color-fill',
  theme: 'light',
  htmltitle: 'ISP'
}

capt.options = {
  el: '#app',
  components: mycomponents,
  vuexs: {
    ispwebstore
  },
  axiosConfig: axiosConfig,
  loginMounted: (that) => {
    // 这是成功登录后取到菜单用户信息后执行事件
    // 如下是用到自定义的store，读取用户类型
    let utype = that.$store.state.userinfo.type
    let typekey = (utype === 1 || utype === 2) ? 'type' : 'type' + utype
    let apiurlall = apilist[typekey]
    that.$store.commit('setApiUrlList', apiurlall)
  },
  meObjCovion: meObjCovion,  
  baseUrl: {
    login: config.proxyPrefix + '/login',
    logout: config.proxyPrefix + '/logout',
    verificon: config.proxyPrefix + '/imgVerify',
    userinfo: config.proxyPrefix + '/user/info',
    menutree: config.proxyPrefix + '/user/menu'
  }
}
capt.createapp()